@@ -56,7 +56,7 @@ INTERNALERROR_CLUSTERNOTFOUND = 'InternalError.ClusterNotFound'
 # Cluster status error.
 INTERNALERROR_CLUSTERSTATE = 'InternalError.ClusterState'
 
-# 
+# The version of the cluster node is outdated.
 INTERNALERROR_CLUSTERUPGRADENODEVERSION = 'InternalError.ClusterUpgradeNodeVersion'
 
 # Internal HTTP client error
@@ -206,7 +206,7 @@ INVALIDPARAMETER_CIDRCONFLICTWITHOTHERROUTE = 'InvalidParameter.CidrConflictWith
 # The CIDR block conflicts with the VPC’s CIDR block.
 INVALIDPARAMETER_CIDRCONFLICTWITHVPCCIDR = 'InvalidParameter.CidrConflictWithVpcCidr'
 
-# 
+# The created route conflicts with the existing global route under the VPC.
 INVALIDPARAMETER_CIDRCONFLICTWITHVPCGLOBALROUTE = 'InvalidParameter.CidrConflictWithVpcGlobalRoute'
 
 # Parameter error. The CIDR block does not meet the specification.
@@ -224,6 +224,9 @@ INVALIDPARAMETER_GATEWAYALREADYASSOCIATEDCIDR = 'InvalidParameter.GatewayAlready
 # Invalid parameter.
 INVALIDPARAMETER_PARAM = 'InvalidParameter.Param'
 
+# The PROM instance does not exist.
+INVALIDPARAMETER_PROMINSTANCENOTFOUND = 'InvalidParameter.PromInstanceNotFound'
+
 # Route table is not empty.
 INVALIDPARAMETER_ROUTETABLENOTEMPTY = 'InvalidParameter.RouteTableNotEmpty'
 
